# LLSE-Python Helper Lib

A typing & util lib for LLSE Python runtime

为 LLSE Python 运行时开发的 类型提示/工具库

## Install / 安装

Use `pip` or other Python package managers to install globally for type hints.

使用 `pip` 或其他包管理器全局安装来提供类型提示

```shell
pip install llpy-helper-lib
```

## Usage / 用法

**[example.py](./example.py)**
